@@ -5,15 +5,17 @@ use lib qw< dlib ../dlib >;
 
 use Keyword::Declare;
 
-keyword inline (Ident $name, List $params, Block $code) {{{
+keyword inline (Ident $name, List $raw_params, Block $code) {{{
     keyword <{$name}> (List $args) {
         my $code   = q[<{ substr($code, 1, -1) =~ s/^\s*return.*//gmr }>];
-        my $params = q[<{$params}>];
-        $params=~s/\s+//gr ne $args=~s/\s+//gr ? qq({ my $params = $args; $code }) : $code;
+        my $cooked_params = q[<{$raw_params}>];
+        $cooked_params =~ s/\s+//gr ne $args=~s/\s+//gr
+            ? qq({ my $cooked_params = $args; $code })
+            : $code;
     }
 
     sub <{$name}> {
-        my <{$params}> = @_;
+        my <{$raw_params}> = @_;
         <{substr $code, 1, -1}>
     }
 }}}
