@@ -1,8 +1,8 @@
 package Keyword::Declare;
-our $VERSION = '0.000003';
+our $VERSION = '0.000004';
 
-# Perl 5.12 required for pluggable keywords...
-use 5.012; use warnings;
+# Perl 5.14 required for pluggable keywords and /.../r
+use 5.014; use warnings;
 
 use Keyword::Simple; # ...This module provides the keyword pluggability
 use PPI;             # ...This module handles the parsing
@@ -133,6 +133,9 @@ sub _install_keyword {
         my (undef, $filename, $linenum) = caller();
         my $linecount = $$ref =~ tr/\n//;
 
+        # Track source modifications...
+        my $pre_source = $$ref;
+
         # Are there any versions of this keyword in scope???
         use Carp;
         my @candidate_indices = @{^H}{grep {/^Keyword::Declare active=$NAME\b/} keys %{^H}}
@@ -273,6 +276,7 @@ sub _install_keyword {
             # Preserve line numbers in the original source file...
             $linenum += $linecount - ($matches[0]{src} =~ tr/\n//);
             $$ref = $new_source . "\n#line $linenum $filename\n" . $matches[0]{src};
+
         }
 
         # If no valid keyword variants are in scope, report a fatal syntax error...
@@ -1143,7 +1147,7 @@ Keyword::Declare - Declare new Perl keywords...via a keyword
 
 =head1 VERSION
 
-This document describes Keyword::Declare version 0.000003
+This document describes Keyword::Declare version 0.000004
 
 
 =head1 STATUS
@@ -1184,14 +1188,26 @@ future releases.
     keyword test (String $desc, Comma, Expr $test) {
         return "use Test::More; ok $test => $desc"
     }
+
     keyword test (Expr $test) {
         my $desc = "q{$test at line }.__LINE__";
         return "use Test::More; ok $test => $desc"
     }
+
     keyword test (String $desc, Block $subtests) {
         return "use Test::More; subtest $desc => sub $subtests;"
     }
 
+    # Keywords declared in an import() are automatically exported...
+    sub import {
+
+        keyword debug (Expr $expr) {
+            return "" if !$ENV{DEBUG};
+            return "use Data::Dump 'ddx'; ddx $expr";
+        }
+
+    }
+
 
 
 =head1 DESCRIPTION
@@ -1852,9 +1868,10 @@ Keyword::Declare requires no configuration files or environment variables.
 
 =head1 DEPENDENCIES
 
-The module is an interface to Perl's pluggable keyword mechanism,
-which was introduced in Perl 5.12. Hence it will not work under
-earlier versions of Perl.
+The module is an interface to Perl's pluggable keyword mechanism, which
+was introduced in Perl 5.12. Hence it will never work under earlier
+versions of Perl. The implementation also uses contructs introduced in
+Perl 5.14, so that is the minimal practical version.
 
 Currently requires both the Key::Declare module and the PPI module.
 
